@@ -3,7 +3,8 @@
 
 import datetime
 import decimal
-import os.path
+import mimetypes
+import re
 
 import flask
 import flask.views
@@ -11,6 +12,12 @@ from flask import request
 from volkanic.utils import merge_dicts
 
 
+def infer_mime_type(filename: str, default="text/plain") -> str:
+    if filename.startswith('.'):
+        filename = '_' + filename
+    return mimetypes.guess_type(filename)[0] or default
+
+
 def respond(*args, **kwargs):
     resp = kwargs
     for arg in args:
@@ -33,6 +40,12 @@ def respond(*args, **kwargs):
     return resp
 
 
+def respond_plain_text(text: str):
+    resp = flask.make_response(text, 200)
+    resp.mimetype = "text/plain"
+    return resp
+
+
 def respond_with_pre_gzipped(content: bytes, content_type=None):
     content_type = content_type or 'text/plain'
     resp = flask.make_response(content)
@@ -41,6 +54,20 @@ def respond_with_pre_gzipped(content: bytes, content_type=None):
     return resp
 
 
+def respond_xaccel_redirect(path: str, filename: str = None):
+    # nginx: http://wiki.nginx.org/NginxXSendfile
+    resp = flask.make_response()
+    headers = {
+        'X-Accel-Redirect': path,
+        'Cache-Control': 'no-cache',
+        'Content-Type': infer_mime_type(path, 'application/octet-stream'),
+        'Content-Disposition':
+            f'attachment; filename={filename}' if filename else 'inline',
+    }
+    resp.headers.update(headers)
+    return resp
+
+
 def get_request_data(force_json=False):
     if request.method == 'GET':
         return request.args.to_dict()
@@ -87,18 +114,19 @@ def _json_default(o):
         return float(o)
     if isinstance(o, datetime.timedelta):
         return o.total_seconds()
-    if isinstance(o, datetime.date):
+    if isinstance(o, datetime.date) and not isinstance(o, datetime.datetime):
         return o.isoformat()
     if hasattr(o, 'as_json_serializable'):
         return o.as_json_serializable()
-    return o
+    raise TypeError
 
 
 def json_default(o):
     """usage: json.dumps(some_o, default=json_default)"""
-    o = _json_default(o)
-    if isinstance(o, str):
-        return o
+    try:
+        return _json_default(o)
+    except TypeError:
+        pass
     if isinstance(o, datetime.datetime):
         return o.strftime(_datetime_fmt)
     return str(o)
@@ -108,16 +136,37 @@ class JSONEncoderPlus(flask.json.JSONEncoder):
     datetime_fmt = _datetime_fmt
 
     def default(self, o):
-        o = _json_default(o)
-        if isinstance(o, str):
-            return o
+        try:
+            return _json_default(o)
+        except TypeError:
+            pass
         if isinstance(o, datetime.datetime):
             return o.strftime(self.datetime_fmt)
-        return super(JSONEncoderPlus, self).default(o)
+        return super().default(o)
 
 
-def infer_mime_type(filename: str, default="text/plain") -> str:
-    from joker.flasky.environ import GlobalInterface
-    gi = GlobalInterface()
-    name, ext = os.path.splitext(filename)
-    return gi.mime_types.get(ext or name, default)
+def serialize_current_session(app: flask.Flask = None):
+    if app is None:
+        app = flask.current_app
+    ss = app.session_interface.get_signing_serializer(app)
+    return ss.dumps(dict(flask.session))
+
+
+class RequestBoundSingletonMeta(type):
+    def __call__(cls, *args, **kwargs):
+        cache = flask.g.setdefault('request_bound_cache', {})
+        try:
+            return cache[cls]
+        except KeyError:
+            obj = super().__call__(*args, **kwargs)
+            return cache.setdefault(cls, obj)
+
+
+def is_mobile():
+    _regex_ua_mobile = re.compile(
+        "Mobile|iP(hone|od|ad)|Android|BlackBerry|IEMobile|Kindle"
+        "|NetFront|Silk-Accelerated|(hpw|web)OS|Fennec|Minimo"
+        "|Opera M(obi|ini)|Blazer|Dolfin|Dolphin|Skyfire|Zune"
+    )
+    ua = flask.request.headers.get('User-Agent', '')
+    return _regex_ua_mobile.search(ua)
